@@ -20,11 +20,10 @@ class QueryAgent:
                 Only use information from the knowledge graph to answer the question. If you don't know the answer, say so.
                 Every time you return a response add a section at the end called "Wish I could find" and state what knowledge you didn't find and wish you could find
                 """),
-                show_tool_calls=True,
                 markdown=True,
                 debug_mode=False,
             )
 
     def query(self, query: str):
-        result = self.agent.run(query)
+        result = self.agent.run("Answer the following question, use as many tools as you need to get the information: {" + query + "}")
         return result.content
\ No newline at end of file
